/*------------------------------------*
  $SEARCHFORM HEADER REPLACE
*------------------------------------*/
#site-header.header-replace #site-navigation .dropdown-menu {
  transition: opacity 0.25s ease-in-out;
  -webkit-transition: opacity 0.25s ease-in-out;
  -moz-transition: opacity 0.25s ease-in-out;
  -o-transition: opacity 0.25s ease-in-out;
  -ms-transition: opacity 0.25s ease-in-out;
}

#site-header.header-replace #site-navigation.hide .dropdown-menu {
  visibility: hidden;
  opacity: 0;
}

#searchform-header-replace {
  position: absolute;
  top: 0;
  right: 0;
  height: 100%;
  width: 100%;
  visibility: hidden;
  opacity: 0;
  transition: opacity 0.25s ease-in-out;
  -webkit-transition: opacity 0.25s ease-in-out;
  -moz-transition: opacity 0.25s ease-in-out;
  -o-transition: opacity 0.25s ease-in-out;
  -ms-transition: opacity 0.25s ease-in-out;
}

#searchform-header-replace form {
  height: 100%;
  width: 100%;
}

#searchform-header-replace input {
  height: 100%;
  width: 94%;
  font-size: 22px;
  background-color: transparent;
  color: #bbb;
  padding: 0;
  outline: 0;
  border: 0;
  margin: 0;
  border-radius: 0;
}

#searchform-header-replace-close {
  position: absolute;
  right: 8px;
  top: 50%;
  margin-top: -20px;
  height: 40px;
  line-height: 40px;
  font-size: 26px;
  color: #bbb;
  cursor: pointer;
  transition: all .3s ease;
}

#searchform-header-replace-close:hover {
  color: #222;
}

/* display search on click */
#searchform-header-replace.show {
  visibility: visible;
  opacity: 1;
}